@@ -24,9 +24,7 @@
 #include <ruby.h>
 #include <libvirt/libvirt.h>
 #include <libvirt/virterror.h>
-#if HAVE_VIRDOMAINLXCENTERSECURITYLABEL
 #include <libvirt/libvirt-lxc.h>
-#endif
 #include "extconf.h"
 #include "common.h"
 #include "storage.h"
@@ -39,6 +37,10 @@
 #include "domain.h"
 #include "stream.h"
 
+#if !LIBVIR_CHECK_VERSION(2, 0, 0)
+# error "Libvirt >= 2.0.0 is required for the ruby binding"
+#endif
+
 static VALUE c_libvirt_version;
 
 VALUE m_libvirt;
@@ -60,7 +62,7 @@ static void rubyLibvirtErrorFunc(void *RUBY_LIBVIRT_UNUSED(userdata),
  * call-seq:
  *   Libvirt::version(type=nil) -> [ libvirt_version, type_version ]
  *
- * Call virGetVersion[http://www.libvirt.org/html/libvirt-libvirt-host.html#virGetVersion]
+ * Call virGetVersion[https://libvirt.org/html/libvirt-libvirt-host.html#virGetVersion]
  * to get the version of libvirt and of the hypervisor TYPE.
  */
 static VALUE libvirt_version(int argc, VALUE *argv,
@@ -90,7 +92,7 @@ static VALUE libvirt_version(int argc, VALUE *argv,
  * call-seq:
  *   Libvirt::open(uri=nil) -> Libvirt::Connect
  *
- * Call virConnectOpen[http://www.libvirt.org/html/libvirt-libvirt-host.html#virConnectOpen]
+ * Call virConnectOpen[https://libvirt.org/html/libvirt-libvirt-host.html#virConnectOpen]
  * to open a connection to a URL.
  */
 static VALUE libvirt_open(int argc, VALUE *argv, VALUE RUBY_LIBVIRT_UNUSED(m))
@@ -111,7 +113,7 @@ static VALUE libvirt_open(int argc, VALUE *argv, VALUE RUBY_LIBVIRT_UNUSED(m))
  * call-seq:
  *   Libvirt::open_read_only(uri=nil) -> Libvirt::Connect
  *
- * Call virConnectOpenReadOnly[http://www.libvirt.org/html/libvirt-libvirt-host.html#virConnectOpenReadOnly]
+ * Call virConnectOpenReadOnly[https://libvirt.org/html/libvirt-libvirt-host.html#virConnectOpenReadOnly]
  * to open a read-only connection to a URL.
  */
 static VALUE libvirt_open_read_only(int argc, VALUE *argv,
@@ -130,7 +132,6 @@ static VALUE libvirt_open_read_only(int argc, VALUE *argv,
     return ruby_libvirt_connect_new(conn);
 }
 
-#if HAVE_VIRCONNECTOPENAUTH
 static int libvirt_auth_callback_wrapper(virConnectCredentialPtr cred,
                                          unsigned int ncred, void *cbdata)
 {
@@ -184,11 +185,11 @@ static int libvirt_auth_callback_wrapper(virConnectCredentialPtr cred,
  * call-seq:
  *   Libvirt::open_auth(uri=nil, credlist=nil, userdata=nil, flags=0) {|...| authentication block} -> Libvirt::Connect
  *
- * Call virConnectOpenAuth[http://www.libvirt.org/html/libvirt-libvirt-host.html#virConnectOpenAuth]
+ * Call virConnectOpenAuth[https://libvirt.org/html/libvirt-libvirt-host.html#virConnectOpenAuth]
  * to open a connection to a libvirt URI, with a possible authentication block.
  * If an authentication block is desired, then credlist should be an array that
  * specifies which credentials the authentication block is willing to support;
- * the full list is available at http://libvirt.org/html/libvirt-libvirt.html#virConnectCredentialType.
+ * the full list is available at https://libvirt.org/html/libvirt-libvirt.html#virConnectCredentialType.
  * If userdata is not nil and an authentication block is given, userdata will
  * be passed unaltered into the authentication block.  The flags parameter
  * controls how to open connection.  The only options currently available for
@@ -262,9 +263,7 @@ static VALUE libvirt_open_auth(int argc, VALUE *argv,
 
     return ruby_libvirt_connect_new(conn);
 }
-#endif
 
-#if HAVE_VIREVENTREGISTERIMPL
 static VALUE add_handle, update_handle, remove_handle;
 static VALUE add_timeout, update_timeout, remove_timeout;
 
@@ -575,7 +574,7 @@ static int is_symbol_proc_or_nil(VALUE handle)
  * call-seq:
  *   Libvirt::event_register_impl(add_handle=nil, update_handle=nil, remove_handle=nil, add_timeout=nil, update_timeout=nil, remove_timeout=nil) -> Qnil
  *
- * Call virEventRegisterImpl[http://www.libvirt.org/html/libvirt-libvirt-event.html#virEventRegisterImpl]
+ * Call virEventRegisterImpl[https://libvirt.org/html/libvirt-libvirt-event.html#virEventRegisterImpl]
  * to register callback handlers for handles and timeouts.  These handles and
  * timeouts are used as part of the libvirt infrastructure for generating
  * domain events.  Each callback must be a Symbol (that is the name of a
@@ -645,9 +644,7 @@ static VALUE libvirt_conn_event_register_impl(int argc, VALUE *argv,
 
     return Qnil;
 }
-#endif
 
-#if HAVE_VIRDOMAINLXCENTERSECURITYLABEL
 /*
  * call-seq:
  *   Libvirt::lxc_enter_security_label(model, label, flags=0) -> Libvirt::Domain::SecurityLabel
@@ -701,7 +698,6 @@ static VALUE libvirt_domain_lxc_enter_security_label(int argc, VALUE *argv,
 
     return result;
 }
-#endif
 
 /*
  * Module Libvirt
@@ -712,7 +708,6 @@ void Init__libvirt(void)
     c_libvirt_version = rb_define_class_under(m_libvirt, "Version",
                                               rb_cObject);
 
-#if HAVE_VIRCONNECTOPENAUTH
     rb_define_const(m_libvirt, "CONNECT_RO", INT2NUM(VIR_CONNECT_RO));
 
     rb_define_const(m_libvirt, "CRED_USERNAME", INT2NUM(VIR_CRED_USERNAME));
@@ -725,12 +720,9 @@ void Init__libvirt(void)
                     INT2NUM(VIR_CRED_NOECHOPROMPT));
     rb_define_const(m_libvirt, "CRED_REALM", INT2NUM(VIR_CRED_REALM));
     rb_define_const(m_libvirt, "CRED_EXTERNAL", INT2NUM(VIR_CRED_EXTERNAL));
-#endif
 
-#if HAVE_CONST_VIR_CONNECT_NO_ALIASES
     rb_define_const(m_libvirt, "CONNECT_NO_ALIASES",
                     INT2NUM(VIR_CONNECT_NO_ALIASES));
-#endif
 
     /*
      * Libvirt Errors
@@ -768,82 +760,32 @@ void Init__libvirt(void)
     rb_define_const(e_Error, "FROM_TEST", INT2NUM(VIR_FROM_TEST));
     rb_define_const(e_Error, "FROM_REMOTE", INT2NUM(VIR_FROM_REMOTE));
     rb_define_const(e_Error, "FROM_OPENVZ", INT2NUM(VIR_FROM_OPENVZ));
-#if HAVE_CONST_VIR_FROM_VMWARE
     rb_define_const(e_Error, "FROM_VMWARE", INT2NUM(VIR_FROM_VMWARE));
-#endif
-#if HAVE_CONST_VIR_FROM_XENXM
     rb_define_const(e_Error, "FROM_XENXM", INT2NUM(VIR_FROM_XENXM));
-#endif
-#if HAVE_CONST_VIR_FROM_STATS_LINUX
     rb_define_const(e_Error, "FROM_STATS_LINUX", INT2NUM(VIR_FROM_STATS_LINUX));
-#endif
-#if HAVE_TYPE_VIR_FROM_LXC
     rb_define_const(e_Error, "FROM_LXC", INT2NUM(VIR_FROM_LXC));
-#endif
-#if HAVE_TYPE_VIRSTORAGEPOOLPTR
     rb_define_const(e_Error, "FROM_STORAGE", INT2NUM(VIR_FROM_STORAGE));
-#endif
-#if HAVE_CONST_VIR_FROM_NETWORK
     rb_define_const(e_Error, "FROM_NETWORK", INT2NUM(VIR_FROM_NETWORK));
-#endif
-#if HAVE_CONST_VIR_FROM_DOMAIN
     rb_define_const(e_Error, "FROM_DOMAIN", INT2NUM(VIR_FROM_DOMAIN));
-#endif
-#if HAVE_CONST_VIR_FROM_UML
     rb_define_const(e_Error, "FROM_UML", INT2NUM(VIR_FROM_UML));
-#endif
-#if HAVE_TYPE_VIRNODEDEVICEPTR
     rb_define_const(e_Error, "FROM_NODEDEV", INT2NUM(VIR_FROM_NODEDEV));
-#endif
-#if HAVE_CONST_VIR_FROM_XEN_INOTIFY
     rb_define_const(e_Error, "FROM_XEN_INOTIFY", INT2NUM(VIR_FROM_XEN_INOTIFY));
-#endif
-#if HAVE_CONST_VIR_FROM_SECURITY
     rb_define_const(e_Error, "FROM_SECURITY", INT2NUM(VIR_FROM_SECURITY));
-#endif
-#if HAVE_CONST_VIR_FROM_VBOX
     rb_define_const(e_Error, "FROM_VBOX", INT2NUM(VIR_FROM_VBOX));
-#endif
-#if HAVE_TYPE_VIRINTERFACEPTR
     rb_define_const(e_Error, "FROM_INTERFACE", INT2NUM(VIR_FROM_INTERFACE));
-#endif
-#if HAVE_CONST_VIR_FROM_ONE
     rb_define_const(e_Error, "FROM_ONE", INT2NUM(VIR_FROM_ONE));
-#endif
-#if HAVE_CONST_VIR_FROM_ESX
     rb_define_const(e_Error, "FROM_ESX", INT2NUM(VIR_FROM_ESX));
-#endif
-#if HAVE_CONST_VIR_FROM_PHYP
     rb_define_const(e_Error, "FROM_PHYP", INT2NUM(VIR_FROM_PHYP));
-#endif
-#if HAVE_TYPE_VIRSECRETPTR
     rb_define_const(e_Error, "FROM_SECRET", INT2NUM(VIR_FROM_SECRET));
-#endif
-#if HAVE_VIRCONNECTCOMPARECPU
     rb_define_const(e_Error, "FROM_CPU", INT2NUM(VIR_FROM_CPU));
-#endif
-#if HAVE_CONST_VIR_FROM_XENAPI
     rb_define_const(e_Error, "FROM_XENAPI", INT2NUM(VIR_FROM_XENAPI));
-#endif
-#if HAVE_TYPE_VIRNWFILTERPTR
     rb_define_const(e_Error, "FROM_NWFILTER", INT2NUM(VIR_FROM_NWFILTER));
-#endif
-#if HAVE_CONST_VIR_FROM_HOOK
     rb_define_const(e_Error, "FROM_HOOK", INT2NUM(VIR_FROM_HOOK));
-#endif
-#if HAVE_TYPE_VIRDOMAINSNAPSHOTPTR
     rb_define_const(e_Error, "FROM_DOMAIN_SNAPSHOT",
                     INT2NUM(VIR_FROM_DOMAIN_SNAPSHOT));
-#endif
-#if HAVE_CONST_VIR_FROM_AUDIT
     rb_define_const(e_Error, "FROM_AUDIT", INT2NUM(VIR_FROM_AUDIT));
-#endif
-#if HAVE_CONST_VIR_FROM_SYSINFO
     rb_define_const(e_Error, "FROM_SYSINFO", INT2NUM(VIR_FROM_SYSINFO));
-#endif
-#if HAVE_CONST_VIR_FROM_STREAMS
     rb_define_const(e_Error, "FROM_STREAMS", INT2NUM(VIR_FROM_STREAMS));
-#endif
 
     /* libvirt error codes */
     rb_define_const(e_Error, "ERR_OK", INT2NUM(VIR_ERR_OK));
@@ -897,10 +839,7 @@ void Init__libvirt(void)
     rb_define_const(e_Error, "ERR_NO_DOMAIN", INT2NUM(VIR_ERR_NO_DOMAIN));
     rb_define_const(e_Error, "ERR_NO_NETWORK", INT2NUM(VIR_ERR_NO_NETWORK));
     rb_define_const(e_Error, "ERR_INVALID_MAC", INT2NUM(VIR_ERR_INVALID_MAC));
-#if HAVE_CONST_VIR_ERR_AUTH_FAILED
     rb_define_const(e_Error, "ERR_AUTH_FAILED", INT2NUM(VIR_ERR_AUTH_FAILED));
-#endif
-#if HAVE_TYPE_VIRSTORAGEPOOLPTR
     rb_define_const(e_Error, "ERR_INVALID_STORAGE_POOL",
                     INT2NUM(VIR_ERR_INVALID_STORAGE_POOL));
     rb_define_const(e_Error, "ERR_INVALID_STORAGE_VOL",
@@ -910,66 +849,43 @@ void Init__libvirt(void)
                     INT2NUM(VIR_ERR_NO_STORAGE_POOL));
     rb_define_const(e_Error, "ERR_NO_STORAGE_VOL",
                     INT2NUM(VIR_ERR_NO_STORAGE_VOL));
-#endif
-#if HAVE_TYPE_VIRNODEDEVICEPTR
     rb_define_const(e_Error, "WAR_NO_NODE", INT2NUM(VIR_WAR_NO_NODE));
     rb_define_const(e_Error, "ERR_INVALID_NODE_DEVICE",
                     INT2NUM(VIR_ERR_INVALID_NODE_DEVICE));
     rb_define_const(e_Error, "ERR_NO_NODE_DEVICE",
                     INT2NUM(VIR_ERR_NO_NODE_DEVICE));
-#endif
-#if HAVE_CONST_VIR_ERR_NO_SECURITY_MODEL
     rb_define_const(e_Error, "ERR_NO_SECURITY_MODEL",
                     INT2NUM(VIR_ERR_NO_SECURITY_MODEL));
-#endif
-#if HAVE_CONST_VIR_ERR_OPERATION_INVALID
     rb_define_const(e_Error, "ERR_OPERATION_INVALID",
                     INT2NUM(VIR_ERR_OPERATION_INVALID));
-#endif
-#if HAVE_TYPE_VIRINTERFACEPTR
     rb_define_const(e_Error, "WAR_NO_INTERFACE", INT2NUM(VIR_WAR_NO_INTERFACE));
     rb_define_const(e_Error, "ERR_NO_INTERFACE", INT2NUM(VIR_ERR_NO_INTERFACE));
     rb_define_const(e_Error, "ERR_INVALID_INTERFACE",
                     INT2NUM(VIR_ERR_INVALID_INTERFACE));
     rb_define_const(e_Error, "ERR_MULTIPLE_INTERFACES",
                     INT2NUM(VIR_ERR_MULTIPLE_INTERFACES));
-#endif
-#if HAVE_TYPE_VIRNWFILTERPTR
     rb_define_const(e_Error, "WAR_NO_NWFILTER", INT2NUM(VIR_WAR_NO_NWFILTER));
     rb_define_const(e_Error, "ERR_INVALID_NWFILTER",
                     INT2NUM(VIR_ERR_INVALID_NWFILTER));
     rb_define_const(e_Error, "ERR_NO_NWFILTER", INT2NUM(VIR_ERR_NO_NWFILTER));
     rb_define_const(e_Error, "ERR_BUILD_FIREWALL",
                     INT2NUM(VIR_ERR_BUILD_FIREWALL));
-#endif
-#if HAVE_TYPE_VIRSECRETPTR
     rb_define_const(e_Error, "WAR_NO_SECRET", INT2NUM(VIR_WAR_NO_SECRET));
     rb_define_const(e_Error, "ERR_INVALID_SECRET",
                     INT2NUM(VIR_ERR_INVALID_SECRET));
     rb_define_const(e_Error, "ERR_NO_SECRET", INT2NUM(VIR_ERR_NO_SECRET));
-#endif
-#if HAVE_CONST_VIR_ERR_CONFIG_UNSUPPORTED
     rb_define_const(e_Error, "ERR_CONFIG_UNSUPPORTED",
                     INT2NUM(VIR_ERR_CONFIG_UNSUPPORTED));
-#endif
-#if HAVE_CONST_VIR_ERR_OPERATION_TIMEOUT
     rb_define_const(e_Error, "ERR_OPERATION_TIMEOUT",
                     INT2NUM(VIR_ERR_OPERATION_TIMEOUT));
-#endif
-#if HAVE_CONST_VIR_ERR_MIGRATE_PERSIST_FAILED
     rb_define_const(e_Error, "ERR_MIGRATE_PERSIST_FAILED",
                     INT2NUM(VIR_ERR_MIGRATE_PERSIST_FAILED));
-#endif
-#if HAVE_CONST_VIR_ERR_HOOK_SCRIPT_FAILED
     rb_define_const(e_Error, "ERR_HOOK_SCRIPT_FAILED",
                     INT2NUM(VIR_ERR_HOOK_SCRIPT_FAILED));
-#endif
-#if HAVE_TYPE_VIRDOMAINSNAPSHOTPTR
     rb_define_const(e_Error, "ERR_INVALID_DOMAIN_SNAPSHOT",
                     INT2NUM(VIR_ERR_INVALID_DOMAIN_SNAPSHOT));
     rb_define_const(e_Error, "ERR_NO_DOMAIN_SNAPSHOT",
                     INT2NUM(VIR_ERR_NO_DOMAIN_SNAPSHOT));
-#endif
 
     /* libvirt levels */
     rb_define_const(e_Error, "LEVEL_NONE", INT2NUM(VIR_ERR_NONE));
@@ -980,11 +896,8 @@ void Init__libvirt(void)
     rb_define_module_function(m_libvirt, "open", libvirt_open, -1);
     rb_define_module_function(m_libvirt, "open_read_only",
                               libvirt_open_read_only, -1);
-#if HAVE_VIRCONNECTOPENAUTH
     rb_define_module_function(m_libvirt, "open_auth", libvirt_open_auth, -1);
-#endif
 
-#if HAVE_VIREVENTREGISTERIMPL
     rb_define_const(m_libvirt, "EVENT_HANDLE_READABLE",
                     INT2NUM(VIR_EVENT_HANDLE_READABLE));
     rb_define_const(m_libvirt, "EVENT_HANDLE_WRITABLE",
@@ -1008,12 +921,9 @@ void Init__libvirt(void)
                               libvirt_event_invoke_handle_callback, 4);
     rb_define_module_function(m_libvirt, "event_invoke_timeout_callback",
                               libvirt_event_invoke_timeout_callback, 2);
-#endif
 
-#if HAVE_VIRDOMAINLXCENTERSECURITYLABEL
     rb_define_method(m_libvirt, "lxc_enter_security_label",
                      libvirt_domain_lxc_enter_security_label, -1);
-#endif
 
     ruby_libvirt_connect_init();
     ruby_libvirt_storage_init();
