@@ -361,6 +361,8 @@ void ruby_libvirt_stream_init(void)
 {
     c_stream = rb_define_class_under(m_libvirt, "Stream", rb_cObject);
     rb_undef_alloc_func(c_stream);
+    rb_define_singleton_method(c_stream, "new",
+                               ruby_libvirt_new_not_allowed, -1);
 
     rb_define_attr(c_stream, "connection", 1, 0);
 
