@@ -7,17 +7,23 @@ $: << File.dirname(__FILE__)
 require 'libvirt'
 require 'test_utils.rb'
 
-# test setup
-begin
-  `rm -f /etc/sysconfig/network-scripts/ifcfg-ruby-libvirt-tester`
-  `brctl delbr ruby-libvirt-tester >& /dev/null`
-rescue
-end
-`rm -f #{$GUEST_DISK} ; qemu-img create -f qcow2 #{$GUEST_DISK} 5G`
-`rm -f /var/lib/libvirt/images/ruby-libvirt-test.save`
-`rm -rf #{$POOL_PATH}; mkdir #{$POOL_PATH} ; echo $?`
+set_test_object("connect")
 
-conn = Libvirt::open("qemu:///system")
+conn = Libvirt::open(URI)
+
+cleanup_test_domain(conn)
+cleanup_test_network(conn)
+
+# test setup
+if !test_default_uri?
+  begin
+    `rm -f /etc/sysconfig/network-scripts/ifcfg-rb-libvirt-test`
+    `brctl delbr rb-libvirt-test >& /dev/null`
+  rescue
+  end
+  `qemu-img create -f qcow2 #{$GUEST_DISK} 5G`
+  `rm -rf #{$POOL_PATH}; mkdir #{$POOL_PATH} ; echo $?`
+end
 
 cpu_xml = <<EOF
 <cpu>
@@ -27,12 +33,12 @@ cpu_xml = <<EOF
 EOF
 
 # TESTGROUP: conn.close
-conn2 = Libvirt::open("qemu:///system")
+conn2 = Libvirt::open(URI)
 expect_too_many_args(conn2, "close", 1)
 expect_success(conn2, "no args", "close")
 
 # TESTGROUP: conn.closed?
-conn2 = Libvirt::open("qemu:///system")
+conn2 = Libvirt::open(URI)
 
 expect_too_many_args(conn2, "closed?", 1)
 expect_success(conn2, "no args", "closed?") {|x| x == false }
@@ -42,7 +48,11 @@ expect_success(conn2, "no args", "closed?") {|x| x == true }
 # TESTGROUP: conn.type
 expect_too_many_args(conn, "type", 1)
 
-expect_success(conn, "no args", "type") {|x| x == "QEMU"}
+if test_default_uri?
+  expect_success(conn, "no args", "type") {|x| x == "TEST"}
+else
+  expect_success(conn, "no args", "type") {|x| x == "QEMU"}
+end
 
 # TESTGROUP: conn.version
 expect_too_many_args(conn, "version", 1)
@@ -62,11 +72,14 @@ expect_success(conn, "no args", "hostname")
 # TESTGROUP: conn.uri
 expect_too_many_args(conn, "uri", 1)
 
-expect_success(conn, "no args", "uri") {|x| x == "qemu:///system" }
+expect_success(conn, "no args", "uri") {|x| x == URI }
 
 # TESTGROUP: conn.max_vcpus
 expect_too_many_args(conn, "max_vcpus", 'kvm', 1)
-expect_fail(conn, Libvirt::RetrieveError, "invalid arg", "max_vcpus", "foo")
+
+if !test_default_uri?
+  expect_fail(conn, Libvirt::RetrieveError, "invalid arg", "max_vcpus", "foo")
+end
 
 expect_success(conn, "no args", "max_vcpus")
 expect_success(conn, "nil arg", "max_vcpus")
@@ -78,35 +91,19 @@ expect_too_many_args(conn, "node_get_info", 1)
 
 expect_success(conn, "no args", "node_get_info")
 
-begin
-  # TESTGROUP: conn.node_free_memory
-  expect_too_many_args(conn, "node_free_memory", 1)
+# TESTGROUP: conn.node_free_memory
+expect_too_many_args(conn, "node_free_memory", 1)
 
-  conn.node_free_memory
-  puts_ok "conn.node_free_memory no args"
-rescue Libvirt::RetrieveError
-  puts_skipped "conn.node_free_memory not supported on this host"
-rescue NoMethodError
-  puts_skipped "conn.node_free_memory does not exist"
-end
+expect_success(conn, "no args", "node_free_memory")
 
-begin
-  # TESTGROUP: conn.node_cells_free_memory
-  expect_too_many_args(conn, "node_cells_free_memory", 1, 2, 3)
-  expect_invalid_arg_type(conn, "node_cells_free_memory", 'start')
-  expect_invalid_arg_type(conn, "node_cells_free_memory", 0, 'end')
+# TESTGROUP: conn.node_cells_free_memory
+expect_too_many_args(conn, "node_cells_free_memory", 1, 2, 3)
+expect_invalid_arg_type(conn, "node_cells_free_memory", 'start')
+expect_invalid_arg_type(conn, "node_cells_free_memory", 0, 'end')
 
-  cell_mem = conn.node_cells_free_memory
-  puts_ok "conn.node_cells_free_memory no args = "
-  cell_mem = conn.node_cells_free_memory(0)
-  puts_ok "conn.node_cells_free_memory(0) = "
-  cell_mem = conn.node_cells_free_memory(0, 1)
-  puts_ok "conn.node_cells_free_memory(0, 1) = "
-rescue Libvirt::RetrieveError
-  puts_skipped "conn.node_cells_free_memory not supported on this host"
-rescue NoMethodError
-  puts_skipped "conn.node_cells_free_memory does not exist"
-end
+expect_success(conn, "no args", "node_cells_free_memory")
+expect_success(conn, "start cell", "node_cells_free_memory", 0)
+expect_success(conn, "start cell and max cells", "node_cells_free_memory", 0, 1)
 
 # TESTGROUP: conn.node_get_security_model
 expect_too_many_args(conn, "node_get_security_model", 1)
@@ -125,27 +122,29 @@ expect_too_many_args(conn, "capabilities", 1)
 expect_success(conn, "no args", "capabilities")
 
 # TESTGROUP: conn.compare_cpu
-expect_too_many_args(conn, "compare_cpu", 1, 2, 3)
-expect_too_few_args(conn, "compare_cpu")
-expect_invalid_arg_type(conn, "compare_cpu", 1)
-expect_invalid_arg_type(conn, "compare_cpu", "hello", 'bar')
-expect_fail(conn, Libvirt::RetrieveError, "invalid XML", "compare_cpu", "hello")
-expect_success(conn, "CPU XML", "compare_cpu", cpu_xml)
+if !test_default_uri?
+  expect_too_many_args(conn, "compare_cpu", 1, 2, 3)
+  expect_too_few_args(conn, "compare_cpu")
+  expect_invalid_arg_type(conn, "compare_cpu", 1)
+  expect_invalid_arg_type(conn, "compare_cpu", "hello", 'bar')
+  expect_fail(conn, Libvirt::RetrieveError, "invalid XML", "compare_cpu", "hello")
+  expect_success(conn, "CPU XML", "compare_cpu", cpu_xml)
+end
 
 # TESTGROUP: conn.baseline_cpu
 expect_too_many_args(conn, "baseline_cpu", 1, 2, 3)
 expect_too_few_args(conn, "baseline_cpu")
 expect_invalid_arg_type(conn, "baseline_cpu", 1)
-expect_invalid_arg_type(conn, "baseline_cpu", [], "foo")
+expect_invalid_arg_type(conn, "baseline_cpu", [cpu_xml], "foo")
 expect_fail(conn, ArgumentError, "empty array", "baseline_cpu", [])
 expect_success(conn, "CPU XML", "baseline_cpu", [cpu_xml])
 
 # TESTGROUP: conn.domain_event_register_any
-dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
+dom_event_callback_proc = lambda {|connect, dom, event, detail, opaque|
 }
 
-def dom_event_callback_symbol(conn, dom, event, detail, opaque)
-end
+# def dom_event_callback_symbol(conn, dom, event, detail, opaque)
+# end
 
 expect_too_many_args(conn, "domain_event_register_any", 1, 2, 3, 4, 5)
 expect_too_few_args(conn, "domain_event_register_any")
@@ -155,58 +154,58 @@ expect_invalid_arg_type(conn, "domain_event_register_any", Libvirt::Connect::DOM
 expect_invalid_arg_type(conn, "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc, 1)
 expect_fail(conn, ArgumentError, "invalid event ID", "domain_event_register_any", 456789, dom_event_callback_proc)
 
-callbackID = expect_success(conn, "eventID and proc", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc)
-conn.domain_event_deregister_any(callbackID)
+# callbackID = expect_success(conn, "eventID and proc", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc)
+# conn.domain_event_deregister_any(callbackID)
 
-callbackID = expect_success(conn, "eventID and symbol", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, :dom_event_callback_symbol)
-conn.domain_event_deregister_any(callbackID)
+# callbackID = expect_success(conn, "eventID and symbol", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, :dom_event_callback_symbol)
+# conn.domain_event_deregister_any(callbackID)
 
-callbackID = expect_success(conn, "eventID, proc, nil domain", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc, nil)
-conn.domain_event_deregister_any(callbackID)
+# callbackID = expect_success(conn, "eventID, proc, nil domain", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc, nil)
+# conn.domain_event_deregister_any(callbackID)
 
-callbackID = expect_success(conn, "eventID, proc, nil domain, opaque", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc, nil, "opaque user data")
-conn.domain_event_deregister_any(callbackID)
+# callbackID = expect_success(conn, "eventID, proc, nil domain, opaque", "domain_event_register_any", Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc, nil, "opaque user data")
+# conn.domain_event_deregister_any(callbackID)
 
-# TESTGROUP: conn.domain_event_deregister_any
-dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
-}
+# # TESTGROUP: conn.domain_event_deregister_any
+# dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
+# }
 
-callbackID = conn.domain_event_register_any(Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc)
+# callbackID = conn.domain_event_register_any(Libvirt::Connect::DOMAIN_EVENT_ID_LIFECYCLE, dom_event_callback_proc)
 
 expect_too_many_args(conn, "domain_event_deregister_any", 1, 2)
 expect_too_few_args(conn, "domain_event_deregister_any")
 expect_invalid_arg_type(conn, "domain_event_deregister_any", "hello")
 
-expect_success(conn, "callbackID", "domain_event_deregister_any", callbackID)
+# expect_success(conn, "callbackID", "domain_event_deregister_any", callbackID)
 
 # TESTGROUP: conn.domain_event_register
-dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
-}
+# dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
+# }
 
-def dom_event_callback_symbol(conn, dom, event, detail, opaque)
-end
+# def dom_event_callback_symbol(conn, dom, event, detail, opaque)
+# end
 
 expect_too_many_args(conn, "domain_event_register", 1, 2, 3)
 expect_too_few_args(conn, "domain_event_register")
 expect_invalid_arg_type(conn, "domain_event_register", "hello")
 
-expect_success(conn, "proc", "domain_event_register", dom_event_callback_proc)
-conn.domain_event_deregister
+# expect_success(conn, "proc", "domain_event_register", dom_event_callback_proc)
+# conn.domain_event_deregister
 
-expect_success(conn, "symbol", "domain_event_register", :dom_event_callback_symbol)
-conn.domain_event_deregister
+# expect_success(conn, "symbol", "domain_event_register", :dom_event_callback_symbol)
+# conn.domain_event_deregister
 
-expect_success(conn, "proc and opaque", "domain_event_register", dom_event_callback_proc, "opaque user data")
-conn.domain_event_deregister
+# expect_success(conn, "proc and opaque", "domain_event_register", dom_event_callback_proc, "opaque user data")
+# conn.domain_event_deregister
 
-# TESTGROUP: conn.domain_event_deregister
-dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
-}
+# # TESTGROUP: conn.domain_event_deregister
+# dom_event_callback_proc = lambda {|conn, dom, event, detail, opaque|
+# }
 
-conn.domain_event_register(dom_event_callback_proc)
+# conn.domain_event_register(dom_event_callback_proc)
 
 expect_too_many_args(conn, "domain_event_deregister", 1)
-expect_success(conn, "no args", "domain_event_deregister")
+# expect_success(conn, "no args", "domain_event_deregister")
 
 # TESTGROUP: conn.num_of_domains
 expect_too_many_args(conn, "num_of_domains", 1)
@@ -216,6 +215,13 @@ expect_success(conn, "no args", "num_of_domains")
 expect_too_many_args(conn, "list_domains", 1)
 expect_success(conn, "no args", "list_domains")
 
+newdom = conn.create_domain_xml($new_dom_xml)
+test_sleep 1
+
+expect_success(conn, "no args", "list_domains")
+
+newdom.destroy
+
 # TESTGROUP: conn.num_of_defined_domains
 expect_too_many_args(conn, "num_of_defined_domains", 1)
 expect_success(conn, "no args", "num_of_defined_domains")
@@ -232,7 +238,7 @@ expect_invalid_arg_type(conn, "create_domain_linux", 1)
 expect_invalid_arg_type(conn, "create_domain_linux", $new_dom_xml, "foo")
 expect_fail(conn, Libvirt::Error, "invalid xml", "create_domain_linux", "hello")
 newdom = expect_success(conn, "domain xml", "create_domain_linux", $new_dom_xml) {|x| x.class == Libvirt::Domain}
-sleep 1
+test_sleep 1
 
 expect_fail(conn, Libvirt::Error, "already existing domain", "create_domain_linux", $new_dom_xml)
 
@@ -246,7 +252,7 @@ expect_invalid_arg_type(conn, "create_domain_xml", 1)
 expect_invalid_arg_type(conn, "create_domain_xml", $new_dom_xml, "foo")
 expect_fail(conn, Libvirt::Error, "invalid xml", "create_domain_xml", "hello")
 newdom = expect_success(conn, "domain xml", "create_domain_xml", $new_dom_xml) {|x| x.class == Libvirt::Domain}
-sleep 1
+test_sleep 1
 
 expect_fail(conn, Libvirt::Error, "already existing domain", "create_domain_xml", $new_dom_xml)
 
@@ -254,23 +260,23 @@ newdom.destroy
 
 # TESTGROUP: conn.lookup_domain_by_name
 newdom = conn.create_domain_xml($new_dom_xml)
-sleep 1
+test_sleep 1
 
 expect_too_many_args(conn, "lookup_domain_by_name", 1, 2)
 expect_too_few_args(conn, "lookup_domain_by_name")
 expect_invalid_arg_type(conn, "lookup_domain_by_name", 1)
 expect_fail(conn, Libvirt::RetrieveError, "non-existent name arg", "lookup_domain_by_name", "foobarbazsucker")
 
-expect_success(conn, "name arg for running domain", "lookup_domain_by_name", "ruby-libvirt-tester") {|x| x.name == "ruby-libvirt-tester"}
+expect_success(conn, "name arg for running domain", "lookup_domain_by_name", "rb-libvirt-test") {|x| x.name == "rb-libvirt-test"}
 newdom.destroy
 
 newdom = conn.define_domain_xml($new_dom_xml)
-expect_success(conn, "name arg for defined domain", "lookup_domain_by_name", "ruby-libvirt-tester") {|x| x.name == "ruby-libvirt-tester"}
+expect_success(conn, "name arg for defined domain", "lookup_domain_by_name", "rb-libvirt-test") {|x| x.name == "rb-libvirt-test"}
 newdom.undefine
 
 # TESTGROUP: conn.lookup_domain_by_id
 newdom = conn.create_domain_xml($new_dom_xml)
-sleep 1
+test_sleep 1
 
 expect_too_many_args(conn, "lookup_domain_by_id", 1, 2)
 expect_too_few_args(conn, "lookup_domain_by_id")
@@ -282,7 +288,7 @@ newdom.destroy
 
 # TESTGROUP: conn.lookup_domain_by_uuid
 newdom = conn.create_domain_xml($new_dom_xml)
-sleep 1
+test_sleep 1
 
 expect_too_many_args(conn, "lookup_domain_by_uuid", 1, 2)
 expect_too_few_args(conn, "lookup_domain_by_uuid")
@@ -297,7 +303,7 @@ expect_success(conn, "UUID arg for defined domain", "lookup_domain_by_uuid", new
 newdom.undefine
 
 # TESTGROUP: conn.define_domain_xml
-expect_too_many_args(conn, "define_domain_xml", 1, 2)
+expect_too_many_args(conn, "define_domain_xml", 1, 2, 3)
 expect_too_few_args(conn, "define_domain_xml")
 expect_invalid_arg_type(conn, "define_domain_xml", 1)
 expect_invalid_arg_type(conn, "define_domain_xml", nil)
@@ -306,32 +312,6 @@ expect_fail(conn, Libvirt::DefinitionError, "invalid XML", "define_domain_xml",
 newdom = expect_success(conn, "domain xml arg", "define_domain_xml", $new_dom_xml)
 newdom.undefine
 
-# TESTGROUP: conn.domain_xml_from_native
-expect_too_many_args(conn, "domain_xml_from_native", 1, 2, 3, 4)
-expect_too_few_args(conn, "domain_xml_from_native")
-expect_too_few_args(conn, "domain_xml_from_native", 1)
-expect_invalid_arg_type(conn, "domain_xml_from_native", 1, 2)
-expect_invalid_arg_type(conn, "domain_xml_from_native", nil, 2)
-expect_invalid_arg_type(conn, "domain_xml_from_native", "qemu-argv", 2)
-expect_invalid_arg_type(conn, "domain_xml_from_native", "qemu-argv", nil)
-expect_invalid_arg_type(conn, "domain_xml_from_native", "qemu-argv", "foo", "bar")
-expect_fail(conn, Libvirt::Error, "unsupported first arg", "domain_xml_from_native", "foo", "bar")
-
-expect_success(conn, "qemu-argv and qemu_cmd_line", "domain_xml_from_native", "qemu-argv", $qemu_cmd_line)
-
-# TESTGROUP: conn.domain_xml_to_native
-expect_too_many_args(conn, "domain_xml_to_native", 1, 2, 3, 4)
-expect_too_few_args(conn, "domain_xml_to_native")
-expect_too_few_args(conn, "domain_xml_to_native", 1)
-expect_invalid_arg_type(conn, "domain_xml_to_native", 1, 2)
-expect_invalid_arg_type(conn, "domain_xml_to_native", nil, 2)
-expect_invalid_arg_type(conn, "domain_xml_to_native", "qemu-argv", 2)
-expect_invalid_arg_type(conn, "domain_xml_to_native", "qemu-argv", nil)
-expect_invalid_arg_type(conn, "domain_xml_to_native", "qemu-argv", "foo", "bar")
-expect_fail(conn, Libvirt::Error, "unsupported first arg", "domain_xml_to_native", "foo", "bar")
-
-expect_success(conn, "qemu-argv and domain XML", "domain_xml_to_native", "qemu-argv", $new_dom_xml)
-
 # TESTGROUP: conn.num_of_interfaces
 expect_too_many_args(conn, "num_of_interfaces", 1)
 expect_success(conn, "no args", "num_of_interfaces")
@@ -356,11 +336,9 @@ expect_too_few_args(conn, "lookup_interface_by_name")
 expect_invalid_arg_type(conn, "lookup_interface_by_name", 1)
 expect_fail(conn, Libvirt::RetrieveError, "non-existent name arg", "lookup_interface_by_name", "foobarbazsucker")
 
-expect_success(conn, "name arg", "lookup_interface_by_name", "ruby-libvirt-tester")
+expect_success(conn, "name arg", "lookup_interface_by_name", "rb-libvirt-test")
 
-newiface.destroy
-
-expect_success(conn, "name arg", "lookup_interface_by_name", "ruby-libvirt-tester")
+expect_success(conn, "name arg", "lookup_interface_by_name", "rb-libvirt-test")
 
 newiface.undefine
 
@@ -372,10 +350,9 @@ expect_too_few_args(conn, "lookup_interface_by_mac")
 expect_invalid_arg_type(conn, "lookup_interface_by_mac", 1)
 expect_fail(conn, Libvirt::RetrieveError, "non-existent mac arg", "lookup_interface_by_mac", "foobarbazsucker")
 
-testiface = find_valid_iface(conn)
-if not testiface.nil?
-  expect_success(conn, "name arg", "lookup_interface_by_mac", testiface.mac) {|x| x.mac == testiface.mac}
-end
+# FIXME: we can't look up an interface by MAC address on an inactive interface,
+# but we also can't start up the interface without a /etc/sysconfig file.
+#expect_success(conn, "mac arg", "lookup_interface_by_mac", $NEW_INTERFACE_MAC) {|x| x.mac == $NEW_INTERFACE_MAC}
 
 newiface.undefine
 
@@ -414,11 +391,11 @@ expect_too_few_args(conn, "lookup_network_by_name")
 expect_invalid_arg_type(conn, "lookup_network_by_name", 1)
 expect_fail(conn, Libvirt::RetrieveError, "non-existent name arg", "lookup_network_by_name", "foobarbazsucker")
 
-expect_success(conn, "name arg", "lookup_network_by_name", "ruby-libvirt-tester")
+expect_success(conn, "name arg", "lookup_network_by_name", "rb-libvirt-test")
 newnet.destroy
 
 newnet = conn.define_network_xml($new_net_xml)
-expect_success(conn, "name arg", "lookup_network_by_name", "ruby-libvirt-tester")
+expect_success(conn, "name arg", "lookup_network_by_name", "rb-libvirt-test")
 newnet.undefine
 
 # TESTGROUP: conn.lookup_network_by_uuid
@@ -491,89 +468,109 @@ expect_fail(conn, Libvirt::Error, "invalid XML", "create_nodedevice_xml", "hello
 #expect_success(conn, "nodedevice XML", "create_nodedevice_xml", "<nodedevice/>")
 
 # TESTGROUP: conn.num_of_nwfilters
-expect_too_many_args(conn, "num_of_nwfilters", 1)
-expect_success(conn, "no args", "num_of_nwfilters")
+if !test_default_uri?
+  expect_too_many_args(conn, "num_of_nwfilters", 1)
+  expect_success(conn, "no args", "num_of_nwfilters")
+end
 
 # TESTGROUP: conn.list_nwfilters
-expect_too_many_args(conn, "list_nwfilters", 1)
-expect_success(conn, "no args", "list_nwfilters")
+if !test_default_uri?
+  expect_too_many_args(conn, "list_nwfilters", 1)
+  expect_success(conn, "no args", "list_nwfilters")
+end
 
 # TESTGROUP: conn.lookup_nwfilter_by_name
-newnw = conn.define_nwfilter_xml($new_nwfilter_xml)
+if !test_default_uri?
+  newnw = conn.define_nwfilter_xml($new_nwfilter_xml)
 
-expect_too_many_args(conn, "lookup_nwfilter_by_name", 1, 2)
-expect_too_few_args(conn, "lookup_nwfilter_by_name")
-expect_invalid_arg_type(conn, "lookup_nwfilter_by_name", 1)
+  expect_too_many_args(conn, "lookup_nwfilter_by_name", 1, 2)
+  expect_too_few_args(conn, "lookup_nwfilter_by_name")
+  expect_invalid_arg_type(conn, "lookup_nwfilter_by_name", 1)
 
-expect_success(conn, "name arg", "lookup_nwfilter_by_name", "ruby-libvirt-tester")
+  expect_success(conn, "name arg", "lookup_nwfilter_by_name", "rb-libvirt-test")
 
-newnw.undefine
+  newnw.undefine
+end
 
 # TESTGROUP: conn.lookup_nwfilter_by_uuid
-newnw = conn.define_nwfilter_xml($new_nwfilter_xml)
+if !test_default_uri?
+  newnw = conn.define_nwfilter_xml($new_nwfilter_xml)
 
-expect_too_many_args(conn, "lookup_nwfilter_by_uuid", 1, 2)
-expect_too_few_args(conn, "lookup_nwfilter_by_uuid")
-expect_invalid_arg_type(conn, "lookup_nwfilter_by_uuid", 1)
+  expect_too_many_args(conn, "lookup_nwfilter_by_uuid", 1, 2)
+  expect_too_few_args(conn, "lookup_nwfilter_by_uuid")
+  expect_invalid_arg_type(conn, "lookup_nwfilter_by_uuid", 1)
 
-expect_success(conn, "uuid arg", "lookup_nwfilter_by_uuid", $NWFILTER_UUID) {|x| x.uuid == $NWFILTER_UUID}
+  expect_success(conn, "uuid arg", "lookup_nwfilter_by_uuid", $NWFILTER_UUID) {|x| x.uuid == $NWFILTER_UUID}
 
-newnw.undefine
+  newnw.undefine
+end
 
 # TESTGROUP: conn.define_nwfilter_xml
-expect_too_many_args(conn, "define_nwfilter_xml", 1, 2)
-expect_too_few_args(conn, "define_nwfilter_xml")
-expect_invalid_arg_type(conn, "define_nwfilter_xml", 1)
-expect_invalid_arg_type(conn, "define_nwfilter_xml", nil)
-expect_fail(conn, Libvirt::DefinitionError, "invalid XML", "define_nwfilter_xml", "hello")
+if !test_default_uri?
+  expect_too_many_args(conn, "define_nwfilter_xml", 1, 2)
+  expect_too_few_args(conn, "define_nwfilter_xml")
+  expect_invalid_arg_type(conn, "define_nwfilter_xml", 1)
+  expect_invalid_arg_type(conn, "define_nwfilter_xml", nil)
+  expect_fail(conn, Libvirt::DefinitionError, "invalid XML", "define_nwfilter_xml", "hello")
 
-newnw = expect_success(conn, "nwfilter XML", "define_nwfilter_xml", $new_nwfilter_xml)
+  newnw = expect_success(conn, "nwfilter XML", "define_nwfilter_xml", $new_nwfilter_xml)
 
-newnw.undefine
+  newnw.undefine
+end
 
 # TESTGROUP: conn.num_of_secrets
-expect_too_many_args(conn, "num_of_secrets", 1)
-expect_success(conn, "no args", "num_of_secrets")
+if !test_default_uri?
+  expect_too_many_args(conn, "num_of_secrets", 1)
+  expect_success(conn, "no args", "num_of_secrets")
+end
 
 # TESTGROUP: conn.list_secrets
-expect_too_many_args(conn, "list_secrets", 1)
-expect_success(conn, "no args", "list_secrets")
+if !test_default_uri?
+  expect_too_many_args(conn, "list_secrets", 1)
+  expect_success(conn, "no args", "list_secrets")
+end
 
 # TESTGROUP: conn.lookup_secret_by_uuid
-newsecret = conn.define_secret_xml($new_secret_xml)
+if !test_default_uri?
+  newsecret = conn.define_secret_xml($new_secret_xml)
 
-expect_too_many_args(conn, "lookup_secret_by_uuid", 1, 2)
-expect_too_few_args(conn, "lookup_secret_by_uuid")
-expect_invalid_arg_type(conn, "lookup_secret_by_uuid", 1)
+  expect_too_many_args(conn, "lookup_secret_by_uuid", 1, 2)
+  expect_too_few_args(conn, "lookup_secret_by_uuid")
+  expect_invalid_arg_type(conn, "lookup_secret_by_uuid", 1)
 
-expect_success(conn, "uuid arg", "lookup_secret_by_uuid", $SECRET_UUID) {|x| x.uuid == $SECRET_UUID}
+  expect_success(conn, "uuid arg", "lookup_secret_by_uuid", $SECRET_UUID) {|x| x.uuid == $SECRET_UUID}
 
-newsecret.undefine
+  newsecret.undefine
+end
 
 # TESTGROUP: conn.lookup_secret_by_usage
-newsecret = conn.define_secret_xml($new_secret_xml)
+if !test_default_uri?
+  newsecret = conn.define_secret_xml($new_secret_xml)
 
-expect_too_many_args(conn, "lookup_secret_by_usage", 1, 2, 3)
-expect_too_few_args(conn, "lookup_secret_by_usage")
-expect_invalid_arg_type(conn, "lookup_secret_by_usage", 'foo', 1)
-expect_invalid_arg_type(conn, "lookup_secret_by_usage", 1, 2)
-expect_fail(conn, Libvirt::RetrieveError, "invalid secret", "lookup_secret_by_usage", Libvirt::Secret::USAGE_TYPE_VOLUME, "foo")
+  expect_too_many_args(conn, "lookup_secret_by_usage", 1, 2, 3)
+  expect_too_few_args(conn, "lookup_secret_by_usage")
+  expect_invalid_arg_type(conn, "lookup_secret_by_usage", 'foo', 1)
+  expect_invalid_arg_type(conn, "lookup_secret_by_usage", 1, 2)
+  expect_fail(conn, Libvirt::RetrieveError, "invalid secret", "lookup_secret_by_usage", Libvirt::Secret::USAGE_TYPE_VOLUME, "foo")
 
-expect_success(conn, "usage type and key", "lookup_secret_by_usage", Libvirt::Secret::USAGE_TYPE_VOLUME, "/var/lib/libvirt/images/mail.img")
+  expect_success(conn, "usage type and key", "lookup_secret_by_usage", Libvirt::Secret::USAGE_TYPE_VOLUME, "/var/lib/libvirt/images/mail.img")
 
-newsecret.undefine
+  newsecret.undefine
+end
 
 # TESTGROUP: conn.define_secret_xml
-expect_too_many_args(conn, "define_secret_xml", 1, 2, 3)
-expect_too_few_args(conn, "define_secret_xml")
-expect_invalid_arg_type(conn, "define_secret_xml", 1)
-expect_invalid_arg_type(conn, "define_secret_xml", nil)
-expect_invalid_arg_type(conn, "define_secret_xml", "hello", 'foo')
-expect_fail(conn, Libvirt::DefinitionError, "invalid XML", "define_secret_xml", "hello")
+if !test_default_uri?
+  expect_too_many_args(conn, "define_secret_xml", 1, 2, 3)
+  expect_too_few_args(conn, "define_secret_xml")
+  expect_invalid_arg_type(conn, "define_secret_xml", 1)
+  expect_invalid_arg_type(conn, "define_secret_xml", nil)
+  expect_invalid_arg_type(conn, "define_secret_xml", "hello", 'foo')
+  expect_fail(conn, Libvirt::DefinitionError, "invalid XML", "define_secret_xml", "hello")
 
-expect_success(conn, "secret XML", "define_secret_xml", $new_secret_xml)
+  expect_success(conn, "secret XML", "define_secret_xml", $new_secret_xml)
 
-newsecret.undefine
+  newsecret.undefine
+end
 
 # TESTGROUP: conn.list_storage_pools
 expect_too_many_args(conn, "list_storage_pools", 1)
@@ -599,12 +596,12 @@ expect_too_few_args(conn, "lookup_storage_pool_by_name")
 expect_invalid_arg_type(conn, "lookup_storage_pool_by_name", 1)
 expect_fail(conn, Libvirt::RetrieveError, "non-existent name arg", "lookup_storage_pool_by_name", "foobarbazsucker")
 
-expect_success(conn, "name arg", "lookup_storage_pool_by_name", "ruby-libvirt-tester")
+expect_success(conn, "name arg", "lookup_storage_pool_by_name", "rb-libvirt-test")
 
 newpool.destroy
 
 newpool = conn.define_storage_pool_xml($new_storage_pool_xml)
-expect_success(conn, "name arg", "lookup_storage_pool_by_name", "ruby-libvirt-tester")
+expect_success(conn, "name arg", "lookup_storage_pool_by_name", "rb-libvirt-test")
 newpool.undefine
 
 # TESTGROUP: conn.lookup_storage_pool_by_uuid
@@ -668,6 +665,169 @@ expect_invalid_arg_type(conn, "sys_info", "foo")
 
 expect_success(conn, "system info", "sys_info")
 
+# TESTGROUP: conn.interface_change_begin
+expect_too_many_args(conn, "interface_change_begin", 1, 2)
+expect_invalid_arg_type(conn, "interface_change_begin", 'hello')
+
+expect_success(conn, "interface change begin", "interface_change_begin")
+
+conn.interface_change_rollback
+
+# TESTGROUP: conn.interface_change_commit
+expect_too_many_args(conn, "interface_change_commit", 1, 2)
+expect_invalid_arg_type(conn, "interface_change_commit", 'foo')
+
+# FIXME: libvirt throws an error on commit with no changes.  What changes can
+# we do here?
+#expect_success(conn, "interface change commit", "interface_change_commit")
+
+# TESTGROUP: conn.interface_change_rollback
+conn.interface_change_begin
+
+expect_too_many_args(conn, "interface_change_rollback", 1, 2)
+expect_invalid_arg_type(conn, "interface_change_rollback", 'foo')
+
+expect_success(conn, "interface change rollback", "interface_change_rollback")
+
+# TESTGROUP: conn.node_cpu_stats
+expect_too_many_args(conn, "node_cpu_stats", 1, 2, 3)
+expect_invalid_arg_type(conn, "node_cpu_stats", 'foo')
+expect_invalid_arg_type(conn, "node_cpu_stats", 1, 'bar')
+
+expect_success(conn, "node cpu stats", "node_cpu_stats")
+
+# TESTGROUP: conn.node_memory_stats
+if !test_default_uri?
+  expect_too_many_args(conn, "node_memory_stats", 1, 2, 3)
+  expect_invalid_arg_type(conn, "node_memory_stats", 'foo')
+  expect_invalid_arg_type(conn, "node_memory_stats", 1, 'bar')
+
+  expect_success(conn, "node memory status", "node_memory_stats")
+end
+
+# TESTGROUP: conn.save_image_xml_desc
+if !test_default_uri?
+  newdom = conn.define_domain_xml($new_dom_xml)
+  newdom.create
+  test_sleep 1
+  newdom.save($GUEST_SAVE)
+
+  expect_too_many_args(conn, "save_image_xml_desc", 1, 2, 3)
+  expect_too_few_args(conn, "save_image_xml_desc")
+  expect_invalid_arg_type(conn, "save_image_xml_desc", nil)
+  expect_invalid_arg_type(conn, "save_image_xml_desc", 1)
+  expect_invalid_arg_type(conn, "save_image_xml_desc", 'foo', 'bar')
+
+  expect_success(conn, "save image path", "save_image_xml_desc", $GUEST_SAVE)
+  `rm -f #{$GUEST_SAVE}`
+end
+
+# TESTGROUP: conn.define_save_image_xml
+expect_too_many_args(conn, "define_save_image_xml", 1, 2, 3, 4)
+expect_too_few_args(conn, "define_save_image_xml")
+expect_too_few_args(conn, "define_save_image_xml", 'foo')
+expect_invalid_arg_type(conn, "define_save_image_xml", nil, 'foo')
+expect_invalid_arg_type(conn, "define_save_image_xml", 1, 'foo')
+expect_invalid_arg_type(conn, "define_save_image_xml", 'foo', nil)
+expect_invalid_arg_type(conn, "define_save_image_xml", 'foo', 1)
+expect_invalid_arg_type(conn, "define_save_image_xml", 'foo', 'bar', 'baz')
+
+# TESTGROUP: conn.alive?
+expect_too_many_args(conn, "alive?", 1)
+
+expect_success(conn, "alive connection", "alive?") {|x| x == true}
+
+# TESTGROUP: conn.list_all_nwfilters
+if !test_default_uri?
+  expect_too_many_args(conn, "list_all_nwfilters", 1, 2)
+  expect_invalid_arg_type(conn, "list_all_nwfilters", "foo")
+
+  expect_success(conn, "no args", "list_all_nwfilters")
+end
+
+# TESTGROUP: conn.list_all_storage_pools
+expect_too_many_args(conn, "list_all_storage_pools", 1, 2)
+expect_invalid_arg_type(conn, "list_all_storage_pools", "foo")
+
+expect_success(conn, "no args", "list_all_storage_pools")
+
+# TESTGROUP: conn.list_all_nodedevices
+expect_too_many_args(conn, "list_all_nodedevices", 1, 2)
+expect_invalid_arg_type(conn, "list_all_nodedevices", "foo")
+
+expect_success(conn, "no args", "list_all_nodedevices")
+
+# TESTGROUP: conn.list_all_secrets
+if !test_default_uri?
+  expect_too_many_args(conn, "list_all_secrets", 1, 2)
+  expect_invalid_arg_type(conn, "list_all_secrets", "foo")
+
+  expect_success(conn, "no args", "list_all_secrets")
+end
+
+# TESTGROUP: conn.list_all_interfaces
+expect_too_many_args(conn, "list_all_interfaces", 1, 2)
+expect_invalid_arg_type(conn, "list_all_interfaces", "foo")
+
+expect_success(conn, "no args", "list_all_interfaces")
+
+# TESTGROUP: conn.list_all_networks
+expect_too_many_args(conn, "list_all_networks", 1, 2)
+expect_invalid_arg_type(conn, "list_all_networks", "foo")
+
+expect_success(conn, "no args", "list_all_networks")
+
+# TESTGROUP: conn.list_all_domains
+expect_too_many_args(conn, "list_all_domains", 1, 2)
+expect_invalid_arg_type(conn, "list_all_domains", "foo")
+
+expect_success(conn, "no args", "list_all_domains")
+
+# TESTGROUP: conn.set_keepalive
+expect_too_many_args(conn, "set_keepalive", 1, 2, 3, 4)
+expect_too_few_args(conn, "set_keepalive")
+expect_too_few_args(conn, "set_keepalive", 1)
+expect_invalid_arg_type(conn, "set_keepalive", 'foo', 0)
+expect_invalid_arg_type(conn, "set_keepalive", 0, 'foo')
+
+# FIXME: somehow we need an event loop implementation for this to work
+#expect_success(conn, "interval and count", "set_keepalive", 1, 10)
+
+# TESTGROUP: conn.node_suspend_for_duration
+expect_too_many_args(conn, "node_suspend_for_duration", 1, 2, 3, 4)
+expect_too_few_args(conn, "node_suspend_for_duration")
+expect_too_few_args(conn, "node_suspend_for_duration", 1)
+expect_invalid_arg_type(conn, "node_suspend_for_duration", 'foo', 1)
+expect_invalid_arg_type(conn, "node_suspend_for_duration", 1, 'foo')
+expect_invalid_arg_type(conn, "node_suspend_for_duration", 1, 2, 'foo')
+
+# TESTGROUP: conn.node_memory_parameters
+if !test_default_uri?
+  expect_too_many_args(conn, "node_memory_parameters", 1, 2)
+  expect_invalid_arg_type(conn, "node_memory_parameters", 'foo')
+
+  expect_success(conn, "no args", "node_memory_parameters")
+end
+
+# TESTGROUP: conn.node_memory_paramters=
+expect_too_many_args(conn, "node_memory_parameters=", 1, 2)
+expect_invalid_arg_type(conn, "node_memory_parameters=", nil)
+expect_invalid_arg_type(conn, "node_memory_parameters=", ['foo', 0])
+expect_invalid_arg_type(conn, "node_memory_parameters=", [{}, 'foo'])
+
+# TESTGROUP: conn.keepalive=
+expect_too_many_args(conn, "keepalive=", 1, 2)
+expect_too_few_args(conn, "keepalive=", [])
+expect_too_few_args(conn, "keepalive=", [1])
+expect_invalid_arg_type(conn, "keepalive=", 1)
+expect_invalid_arg_type(conn, "keepalive=", ['foo', 1])
+expect_invalid_arg_type(conn, "keepalive=", [1, 'foo'])
+
+# FIXME: somehow we need an event loop implementation for this to work
+#expect_success(conn, "interval and count", "keepalive=", 1, 10)
+
+# END TESTS
+
 conn.close
 
 finish_tests
